@@ -1,9 +1,11 @@
-#' Nonlinear Least Squares Fit for OSL surface exposure data
+#' @title Nonlinear Least Squares Fit for OSL surface exposure data
 #'
+#' @description
 #' This function determines the (weighted) least-squares estimates of the
 #' parameters of either equation 1 in *Sohbati et al. (2012a)* or equation 12 in
 #' *Sohbati et al. (2012b)* for a given OSL surface exposure data set (**BETA**).
 #'
+#' @details
 #' **Weighted fitting**
 #'
 #' If `weights = TRUE` the function will use the inverse square of the error (\eqn{1/\sigma^2})
@@ -14,7 +16,6 @@
 #' fitting.
 #'
 #' **Dose rate**
-#'
 #' If any of the arguments `Ddot` or `D0` is at its default value (`NULL`),
 #' this function will fit equation 1 in Sohbati et al. (2012a) to the data. If
 #' the effect of dose rate (i.e., signal saturation) needs to be considered,
@@ -28,7 +29,6 @@
 #' constant.
 #'
 #' **Global fitting**
-#'
 #' If `data` is [list] of multiple `data.frame`s, each representing a separate
 #' sample, the function automatically performs a global fit to the data. This
 #' may be useful to better constrain the parameters `sigmaphi` or `mu` and
@@ -165,7 +165,10 @@
 #' # Known parameters: 10000 a, mu = 0.9, sigmaphi = 5e-10
 #' sample_1 <- ExampleData.SurfaceExposure$sample_1
 #' head(sample_1)
-#' results <- fit_SurfaceExposure(sample_1, mu = 0.9, sigmaphi = 5e-10)
+#' results <- fit_SurfaceExposure(
+#'  data = sample_1,
+#'  mu = 0.9,
+#'  sigmaphi = 5e-10)
 #' get_RLum(results)
 #'
 #'
@@ -174,17 +177,22 @@
 #' # dose rate = 2.5 Gy/ka, D0 = 40 Gy
 #' sample_2 <- ExampleData.SurfaceExposure$sample_2
 #' head(sample_2)
-#' results <- fit_SurfaceExposure(sample_2, mu = 0.9, sigmaphi = 5e-10,
-#'                                Ddot = 2.5, D0 = 40)
+#' results <- fit_SurfaceExposure(
+#'  data = sample_2,
+#'  mu = 0.9,
+#'  sigmaphi = 5e-10,
+#'  Ddot = 2.5,
+#'  D0 = 40)
 #' get_RLum(results)
 #'
-#'
 #' ## Example 3 - Multiple samples (global fit) to better constrain 'mu'
 #' # Known parameters: ages = 1e3, 1e4, 1e5, 1e6 a, mu = 0.9, sigmaphi = 5e-10
 #' set_1 <- ExampleData.SurfaceExposure$set_1
 #' str(set_1, max.level = 2)
-#' results <- fit_SurfaceExposure(set_1, age = c(1e3, 1e4, 1e5, 1e6),
-#'                                sigmaphi = 5e-10)
+#' results <- fit_SurfaceExposure(
+#'   data = set_1,
+#'   age = c(1e3, 1e4, 1e5, 1e6),
+#'   sigmaphi = 5e-10)
 #' get_RLum(results)
 #'
 #'
@@ -193,23 +201,29 @@
 #' # dose rate = 1.0 Ga/ka, D0 = 40 Gy
 #' set_2 <- ExampleData.SurfaceExposure$set_2
 #' str(set_2, max.level = 2)
-#' results <- fit_SurfaceExposure(set_2, age = c(1e2, 1e3, 1e4, 1e5, 1e6),
-#'                                sigmaphi = 5e-10, Ddot = 1, D0 = 40)
-#' get_RLum(results)
+#' results <- fit_SurfaceExposure(
+#'  data = set_2,
+#'  age = c(1e2, 1e3, 1e4, 1e5, 1e6),
+#'  sigmaphi = 5e-10,
+#'  Ddot = 1,
+#'  D0 = 40)
+#'get_RLum(results)
 #'
 #' @md
 #' @export
-fit_SurfaceExposure <- function(data,
-                                sigmaphi = NULL,
-                                mu = NULL,
-                                age = NULL,
-                                Ddot = NULL,
-                                D0 = NULL,
-                                weights = FALSE,
-                                plot = TRUE,
-                                legend = TRUE,
-                                error_bars = TRUE,
-                                coord_flip = FALSE, ...) {
+fit_SurfaceExposure <- function(
+    data,
+    sigmaphi = NULL,
+    mu = NULL,
+    age = NULL,
+    Ddot = NULL,
+    D0 = NULL,
+    weights = FALSE,
+    plot = TRUE,
+    legend = TRUE,
+    error_bars = TRUE,
+    coord_flip = FALSE,
+...) {
 
   ## SETTINGS ----
   settings <- list(
